summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/smpppdsearcher.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/plugins/smpppdcs/smpppdsearcher.cpp')
-rw-r--r--kopete/plugins/smpppdcs/smpppdsearcher.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/plugins/smpppdcs/smpppdsearcher.cpp b/kopete/plugins/smpppdcs/smpppdsearcher.cpp
index a06e30a9..4ec77196 100644
--- a/kopete/plugins/smpppdcs/smpppdsearcher.cpp
+++ b/kopete/plugins/smpppdcs/smpppdsearcher.cpp
@@ -64,7 +64,7 @@ void SMPPPDSearcher::searchNetwork() {
void SMPPPDSearcher::slotStdoutReceivedIfconfig(KProcess * /* proc */, char * buf, int len) {
kdDebug(14312) << k_funcinfo << endl;
- TQString myBuf = TQString::fromLatin1(buf,len);
+ TQString myBuf = TQString::tqfromLatin1(buf,len);
TQRegExp rex("^[ ]{10}.*inet addr:([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}).*Mask:([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3})");
// tokenize the string into lines
TQStringList toks = TQStringList::split("\n", myBuf);
@@ -82,7 +82,7 @@ void SMPPPDSearcher::slotStdoutReceivedNetstat(KProcess * /* proc */, char * buf
kdDebug(14312) << k_funcinfo << endl;
TQRegExp rexGW(".*\\n0.0.0.0[ ]*([0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}).*");
- TQString myBuf = TQString::fromLatin1(buf,len);
+ TQString myBuf = TQString::tqfromLatin1(buf,len);
if(!(rexGW.exactMatch(myBuf) && scan(rexGW.cap(1), "255.255.255.255"))) {
// if netstat -r found no gateway we search the network
@@ -105,8 +105,8 @@ void SMPPPDSearcher::slotStdoutReceivedNetstat(KProcess * /* proc */, char * buf
/*!
\fn SMPPPDSearcher::scan() const
*/
-bool SMPPPDSearcher::scan(const TQString& ip, const TQString& mask) {
- kdDebug(14312) << k_funcinfo << "Scanning " << ip << "/" << mask << "..." << endl;
+bool SMPPPDSearcher::scan(const TQString& ip, const TQString& tqmask) {
+ kdDebug(14312) << k_funcinfo << "Scanning " << ip << "/" << tqmask << "..." << endl;
SMPPPD::Client client;
@@ -123,7 +123,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& mask) {
uint min_range = 0;
uint max_range = 255;
// calculate ip range (only last mask entry)
TQRegExp lastRex("([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})");
if(lastRex.exactMatch(ip)) {
@@ -134,7 +134,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& mask) {
ipToks.push_back(lastRex.cap(i));
}
- if(lastRex.exactMatch(mask)) {
+ if(lastRex.exactMatch(tqmask)) {
uint lastWordMask = lastRex.cap(4).toUInt();
if(lastWordMask == 0) {
@@ -123,7 +123,7 @@ bool SMPPPDSearcher::scan(const TQString& ip, const TQString& mask) {
uint min_range = 0;
uint max_range = 255;
- // calculate ip range (only last mask entry)
+ // calculate ip range (only last tqmask entry)
TQRegExp lastRex("([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})\\.([0-9]{1,3})");
if(lastRex.exactMatch(ip)) {